
from __future__ import print_function, unicode_literals, absolute_import, division
from reahl.doc.examples.features.tabbedpanel.tabbedpanel import TabbedPanelUI

web.site_root = TabbedPanelUI
